@@ -4,11 +4,12 @@
 #' @param code R code string
 #' @param echo whether or not display R code
 #' @param landscape Logical. Whether or not make a landscape section.
-#' @importFrom officer add_slide ph_with_text  body_add_par body_end_section_landscape body_end_section_portrait
-#' @importFrom flextable body_add_flextable ph_with_flextable ph_with_flextable_at
+#' @importFrom officer add_slide ph_with body_add_par body_end_section_landscape body_end_section_portrait
+#' @importFrom flextable body_add_flextable
 #' @return a document object
 #' @export
 #' @examples
+#' \donttest{
 #' require(rrtable)
 #' require(moonBook)
 #' require(officer)
@@ -21,8 +22,8 @@
 #' doc %>% add_text(title=title) %>%
 #'         add_flextable(ftable) %>%
 #'         add_text(title=title2) %>%
-#'         add_flextable(ft) %>%
-#'         print(target=paste0(tempdir(),"/","mytable.docx"))
+#'         add_flextable(ft)
+#'}
 add_flextable=function(mydoc,ftable,echo=FALSE,code="",landscape=FALSE){
      if("mytable" %in% class(ftable)){
           ft<-mytable2flextable(ftable)
@@ -33,7 +34,7 @@ add_flextable=function(mydoc,ftable,echo=FALSE,code="",landscape=FALSE){
      if(echo & (code!="")) pos=2
      if(class(mydoc)=="rpptx"){
 
-              mydoc<-mydoc %>% ph_with_flextable_at(value=ft,left=1,top=pos)
+              mydoc<-mydoc %>% ph_with(value=ft,location = ph_location(left=1,top=pos))
      } else {
           if(landscape) mydoc <- body_end_section_portrait(mydoc)
           mydoc<-mydoc %>% body_add_flextable(ft)
